==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_functions/mp0108_001/CommentsReq.java <==

package net.datastream.schemas.mp_functions.mp0108_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.FOREIGNENTITYCOMMENTID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMENTTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYKEYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOREIGNENTITYCOMMENTID" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="remove_html_tags" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entity",
    "commenttype",
    "entitykeycode",
    "foreignentitycommentid"
})
@XmlRootElement(name = "CommentsReq")
public class CommentsReq {

    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlElement(name = "COMMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type commenttype;
    @XmlElement(name = "ENTITYKEYCODE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entitykeycode;
    @XmlElement(name = "FOREIGNENTITYCOMMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<FOREIGNENTITYCOMMENTID_Type> foreignentitycommentid;
    @XmlAttribute(name = "remove_html_tags")
    protected String remove_Html_Tags;

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété commenttype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCOMMENTTYPE() {
        return commenttype;
    }

    /**
     * Définit la valeur de la propriété commenttype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCOMMENTTYPE(TYPE_Type value) {
        this.commenttype = value;
    }

    /**
     * Obtient la valeur de la propriété entitykeycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYKEYCODE() {
        return entitykeycode;
    }

    /**
     * Définit la valeur de la propriété entitykeycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYKEYCODE(String value) {
        this.entitykeycode = value;
    }

    /**
     * Gets the value of the foreignentitycommentid property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the foreignentitycommentid property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFOREIGNENTITYCOMMENTID().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link FOREIGNENTITYCOMMENTID_Type }
     * 
     * 
     */
    public List<FOREIGNENTITYCOMMENTID_Type> getFOREIGNENTITYCOMMENTID() {
        if (foreignentitycommentid == null) {
            foreignentitycommentid = new ArrayList<FOREIGNENTITYCOMMENTID_Type>();
        }
        return this.foreignentitycommentid;
    }

    /**
     * Obtient la valeur de la propriété remove_Html_Tags.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRemove_Html_Tags() {
        if (remove_Html_Tags == null) {
            return "false";
        } else {
            return remove_Html_Tags;
        }
    }

    /**
     * Définit la valeur de la propriété remove_Html_Tags.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRemove_Html_Tags(String value) {
        this.remove_Html_Tags = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_functions/mp0108_001/CommentsReq.java <==

package net.datastream.schemas.mp_functions.mp0108_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.FOREIGNENTITYCOMMENTID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMENTTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYKEYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOREIGNENTITYCOMMENTID" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="remove_html_tags" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "entity",
    "commenttype",
    "entitykeycode",
    "foreignentitycommentid"
})
@XmlRootElement(name = "CommentsReq")
public class CommentsReq {

    @XmlElement(name = "ENTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entity;
    @XmlElement(name = "COMMENTTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TYPE_Type commenttype;
    @XmlElement(name = "ENTITYKEYCODE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String entitykeycode;
    @XmlElement(name = "FOREIGNENTITYCOMMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<FOREIGNENTITYCOMMENTID_Type> foreignentitycommentid;
    @XmlAttribute(name = "remove_html_tags")
    protected String remove_Html_Tags;

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the commenttype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getCOMMENTTYPE() {
        return commenttype;
    }

    /**
     * Sets the value of the commenttype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setCOMMENTTYPE(TYPE_Type value) {
        this.commenttype = value;
    }

    /**
     * Gets the value of the entitykeycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITYKEYCODE() {
        return entitykeycode;
    }

    /**
     * Sets the value of the entitykeycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITYKEYCODE(String value) {
        this.entitykeycode = value;
    }

    /**
     * Gets the value of the foreignentitycommentid property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the foreignentitycommentid property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFOREIGNENTITYCOMMENTID().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link FOREIGNENTITYCOMMENTID_Type }
     * 
     * 
     */
    public List<FOREIGNENTITYCOMMENTID_Type> getFOREIGNENTITYCOMMENTID() {
        if (foreignentitycommentid == null) {
            foreignentitycommentid = new ArrayList<FOREIGNENTITYCOMMENTID_Type>();
        }
        return this.foreignentitycommentid;
    }

    /**
     * Gets the value of the remove_Html_Tags property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRemove_Html_Tags() {
        if (remove_Html_Tags == null) {
            return "false";
        } else {
            return remove_Html_Tags;
        }
    }

    /**
     * Sets the value of the remove_Html_Tags property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRemove_Html_Tags(String value) {
        this.remove_Html_Tags = value;
    }

}
